@@ -2,11 +2,9 @@
 # Copyright (C) 2009 Timothy P. Hunter
 module Magick
     class RVG
-
         # This is a standard deep_copy method that is used in most classes.
         # Thanks to Robert Klemme.
         module Duplicatable
-
             def deep_copy(h = {})
                 # Prevent recursion. If we reach the
                 # object we started with, stop copying.
@@ -31,12 +29,10 @@ module Magick
                     end
                     copy.freeze if frozen?
                 end
-                return copy
+                copy
             end
-
         end     # module Duplicatable
 
-
         # Convert an array of method arguments to Float objects. If any
         # cannot be converted, raise ArgumentError and issue a message.
         def self.fmsg(*args)
@@ -52,9 +48,9 @@ module Magick
             begin
                 fargs = args.collect { |a| (allow_nil && a.nil?) ? a : Float(a) }
             rescue ArgumentError, TypeError
-                raise ArgumentError, self.fmsg(*args)
+                raise ArgumentError, fmsg(*args)
             end
-            return fargs
+            fargs
         end
 
         def self.convert_one_to_float(arg)
@@ -63,22 +59,15 @@ module Magick
             rescue ArgumentError, TypeError
                 raise ArgumentError, "argument cannot be converted to Float (got #{arg.class})"
             end
-            return farg
+            farg
         end
-
     end # class RVG
 end # module Magick
 
-
-
-
-
 module Magick
     class RVG
         class Utility
-
             class TextStrategy
-
                 def initialize(context)
                     @ctx = context
                     @ctx.shadow.affine = @ctx.text_attrs.affine
@@ -100,13 +89,13 @@ module Magick
 
                     # escape existing braces, surround with braces
                     text.gsub!(/[}]/) { |b| '\\' + b }
-                    return '{' +  text + '}'
+                    '{' +  text + '}'
                 end
 
                 def glyph_metrics(glyph_orientation, glyph)
-                    gm = @ctx.shadow.get_type_metrics("a" + glyph + "a")
-                    gm2 = @ctx.shadow.get_type_metrics("aa")
-                    h = (gm.ascent - gm.descent + 0.5 ).to_i
+                    gm = @ctx.shadow.get_type_metrics('a' + glyph + 'a')
+                    gm2 = @ctx.shadow.get_type_metrics('aa')
+                    h = (gm.ascent - gm.descent + 0.5).to_i
                     w = gm.width - gm2.width
                     if glyph_orientation == 0 || glyph_orientation == 180
                         [w, h]
@@ -122,7 +111,7 @@ module Magick
                     words = text.split(::Magick::RVG::WORD_SEP)
                     words.each do |word|
                         unless first_word
-                            wx, wy = get_word_spacing()
+                            wx, wy = get_word_spacing
                             x_rel_coords << wx
                             y_rel_coords << wy
                         end
@@ -147,7 +136,7 @@ module Magick
                         when :baseline
                             x = 0
                         when :sub
-                            ;
+
                         when :super
                             x = -x
                         when /[-+]?(\d+)%/
@@ -156,7 +145,7 @@ module Magick
                         else
                             x = -@ctx.text_attrs.baseline_shift
                     end
-                    return x
+                    x
                 end
 
                 def render_glyph(glyph_orientation, x, y, glyph)
@@ -171,12 +160,10 @@ module Magick
                         @ctx.gc.pop
                     end
                 end
-
             end     # class TextStrategy
 
             class LRTextStrategy < TextStrategy
-
-                def get_word_spacing()
+                def get_word_spacing
                     @word_space ||= glyph_metrics(@ctx.text_attrs.glyph_orientation_horizontal, ' ')[0]
                     [@word_space + @ctx.text_attrs.word_spacing, 0]
                 end
@@ -192,7 +179,7 @@ module Magick
                     dy = y_rel_coords.max
 
                     # We're handling the anchoring.
-                    @ctx.gc.push()
+                    @ctx.gc.push
                     @ctx.gc.text_anchor(Magick::StartAnchor)
                     if @ctx.text_attrs.text_anchor == :end
                         x -= dx
@@ -203,7 +190,7 @@ module Magick
                     # Align the first glyph
                     case @ctx.text_attrs.glyph_orientation_horizontal
                         when 0
-                            ;
+
                         when 90
                             y -= dy
                         when 180
@@ -228,24 +215,19 @@ module Magick
                         end
                     end
 
-                    @ctx.gc.pop()
+                    @ctx.gc.pop
                     [dx, 0]
                 end
-
             end     # class LRTextStrategy
 
             class RLTextStrategy < TextStrategy
-
                 def render(x, y, text)
-                    raise NotImplementedError
+                    fail NotImplementedError
                 end
-
             end     # class RLTextStrategy
 
-
             class TBTextStrategy < TextStrategy
-
-                def get_word_spacing()
+                def get_word_spacing
                     @word_space ||= glyph_metrics(@ctx.text_attrs.glyph_orientation_vertical, ' ')[1]
                     [0, @word_space + @ctx.text_attrs.word_spacing]
                 end
@@ -261,7 +243,7 @@ module Magick
                     dy = y_rel_coords.inject(0) {|sum, a| sum + a}
 
                     # We're handling the anchoring.
-                    @ctx.gc.push()
+                    @ctx.gc.push
                     @ctx.gc.text_anchor(Magick::StartAnchor)
                     if @ctx.text_attrs.text_anchor == :end
                         y -= dy
@@ -308,15 +290,13 @@ module Magick
                         end
                     end
 
-                    @ctx.gc.pop()
+                    @ctx.gc.pop
                     [0, dy]
                 end
-
             end     # class TBTextStrategy
 
             # Handle "easy" text
             class DefaultTextStrategy < TextStrategy
-
                 def render(x, y, text)
                     @ctx.gc.text(x, y, enquote(text))
                     tm = @ctx.shadow.get_type_metrics(text)
@@ -330,46 +310,39 @@ module Magick
                           end
                     [dx, 0]
                 end
-
             end     # class NormalTextStrategy
-
         end # class Utility
     end # class RVG
 end # module Magick
 
-
-
-
 module Magick
     class RVG
         class Utility
-
             class TextAttributes
-
               public
 
                 WRITING_MODE = %w{lr-tb lr rl-tb rl tb-rl tb}
 
-                def initialize()
-                    @affine = Array.new
+                def initialize
+                    @affine = []
                     @affine << Magick::AffineMatrix.new(1, 0, 0, 1, 0, 0)
-                    @baseline_shift = Array.new
+                    @baseline_shift = []
                     @baseline_shift << :baseline
-                    @glyph_orientation_horizontal = Array.new
+                    @glyph_orientation_horizontal = []
                     @glyph_orientation_horizontal << 0
-                    @glyph_orientation_vertical = Array.new
+                    @glyph_orientation_vertical = []
                     @glyph_orientation_vertical << 90
-                    @letter_spacing = Array.new
+                    @letter_spacing = []
                     @letter_spacing << 0
-                    @text_anchor = Array.new
+                    @text_anchor = []
                     @text_anchor << :start
-                    @word_spacing = Array.new
+                    @word_spacing = []
                     @word_spacing << 0
-                    @writing_mode = Array.new
+                    @writing_mode = []
                     @writing_mode << 'lr-tb'
                 end
 
-                def push()
+                def push
                     @affine.push(@affine.last.dup)
                     @baseline_shift.push(@baseline_shift.last)
                     @text_anchor.push(@text_anchor.last)
@@ -380,7 +353,7 @@ module Magick
                     @word_spacing.push(@word_spacing.last)
                 end
 
-                def pop()
+                def pop
                     @affine.pop
                     @baseline_shift.pop
                     @text_anchor.pop
@@ -400,11 +373,11 @@ module Magick
                     @affine[-1].ty = ty
                 end
 
-                def affine()
+                def affine
                     @affine[-1]
                 end
 
-                def baseline_shift()
+                def baseline_shift
                     @baseline_shift[-1]
                 end
 
@@ -412,7 +385,7 @@ module Magick
                     @baseline_shift[-1] = value
                 end
 
-                def text_anchor()
+                def text_anchor
                     @text_anchor[-1]
                 end
 
@@ -420,7 +393,7 @@ module Magick
                     @text_anchor[-1] = anchor
                 end
 
-                def glyph_orientation_vertical()
+                def glyph_orientation_vertical
                     @glyph_orientation_vertical[-1]
                 end
 
@@ -428,7 +401,7 @@ module Magick
                     @glyph_orientation_vertical[-1] = angle
                 end
 
-                def glyph_orientation_horizontal()
+                def glyph_orientation_horizontal
                     @glyph_orientation_horizontal[-1]
                 end
 
@@ -436,7 +409,7 @@ module Magick
                     @glyph_orientation_horizontal[-1] = angle
                 end
 
-                def letter_spacing()
+                def letter_spacing
                     @letter_spacing[-1]
                 end
 
@@ -450,7 +423,7 @@ module Magick
                     @glyph_orientation_horizontal[-1] != 0
                 end
 
-                def word_spacing()
+                def word_spacing
                     @word_spacing[-1]
                 end
 
@@ -458,18 +431,16 @@ module Magick
                     @word_spacing[-1] = value
                 end
 
-                def writing_mode()
+                def writing_mode
                     @writing_mode[-1]
                 end
 
                 def writing_mode=(mode)
                     @writing_mode[-1] = WRITING_MODE.include?(mode) ? mode : 'lr-tb'
                 end
-
             end     # class TextAttributes
 
             class GraphicContext
-
                 FONT_STRETCH =    {:normal          => Magick::NormalStretch,
                                    :ultra_condensed => Magick::UltraCondensedStretch,
                                    :extra_condensed => Magick::ExtraCondensedStretch,
@@ -506,19 +477,19 @@ module Magick
                                     'rt-tb'=>RLTextStrategy, 'rl'=>RLTextStrategy,
                                     'tb-rl'=>TBTextStrategy, 'tb'=>TBTextStrategy}
 
-                def GraphicContext.degrees_to_radians(deg)
+                def self.degrees_to_radians(deg)
                     Math::PI * (deg % 360.0) / 180.0
                 end
 
               private
 
-                def init_matrix()
+                def init_matrix
                     @rx = @ry = 0
                     @sx = @sy = 1
                     @tx = @ty = 0
                 end
 
-                def concat_matrix()
+                def concat_matrix
                     curr = @text_attrs.affine
                     sx = curr.sx * @sx + curr.ry * @rx
                     rx = curr.rx * @sx + curr.sy * @rx
@@ -527,19 +498,19 @@ module Magick
                     tx = curr.sx * @tx + curr.ry * @ty + curr.tx
                     ty = curr.rx * @tx + curr.sy * @ty + curr.ty
                     @text_attrs.set_affine(sx, rx, ry, sy, tx, ty)
-                    init_matrix()
+                    init_matrix
                 end
 
               public
 
                 attr_reader :gc, :text_attrs
 
-                def initialize()
+                def initialize
                     @gc = Magick::Draw.new
-                    @shadow = Array.new
+                    @shadow = []
                     @shadow << Magick::Draw.new
                     @text_attrs = TextAttributes.new
-                    init_matrix()
+                    init_matrix
                 end
 
                 def method_missing(methID, *args, &block)
@@ -617,7 +588,7 @@ module Magick
                     nil
                 end
 
-                def inspect()
+                def inspect
                     @gc.inspect
                 end
 
@@ -626,14 +597,14 @@ module Magick
                     nil
                 end
 
-                def push()
+                def push
                     @gc.push
                     @shadow.push(@shadow.last.dup)
                     @text_attrs.push
                     nil
                 end
 
-                def pop()
+                def pop
                     @gc.pop
                     @shadow.pop
                     @text_attrs.pop
@@ -647,7 +618,7 @@ module Magick
                     @rx =  Math.sin(GraphicContext.degrees_to_radians(degrees))
                     @ry = -Math.sin(GraphicContext.degrees_to_radians(degrees))
                     @sy =  Math.cos(GraphicContext.degrees_to_radians(degrees))
-                    concat_matrix()
+                    concat_matrix
                     nil
                 end
 
@@ -655,11 +626,11 @@ module Magick
                     sx, sy = Magick::RVG.convert_to_float(sx, sy)
                     @gc.scale(sx, sy)
                     @sx, @sy = sx, sy
-                    concat_matrix()
+                    concat_matrix
                     nil
                 end
 
-                def shadow()
+                def shadow
                     @shadow.last
                 end
 
@@ -667,7 +638,7 @@ module Magick
                     degrees = Magick::RVG.convert_one_to_float(degrees)
                     @gc.skewX(degrees)
                     @ry = Math.tan(GraphicContext.degrees_to_radians(degrees))
-                    concat_matrix()
+                    concat_matrix
                     nil
                 end
 
@@ -675,7 +646,7 @@ module Magick
                     degrees = Magick::RVG.convert_one_to_float(degrees)
                     @gc.skewY(degrees)
                     @rx = Math.tan(GraphicContext.degrees_to_radians(degrees))
-                    concat_matrix()
+                    concat_matrix
                     nil
                 end
 
@@ -694,7 +665,7 @@ module Magick
                         text_renderer = DefaultTextStrategy.new(self)
                     end
 
-                    return text_renderer.render(x, y, text)
+                    text_renderer.render(x, y, text)
                 end
 
                 def text_anchor(anchor)
@@ -718,7 +689,7 @@ module Magick
                     tx, ty = Magick::RVG.convert_to_float(tx, ty)
                     @gc.translate(tx, ty)
                     @tx, @ty = tx, ty
-                    concat_matrix()
+                    concat_matrix
                     nil
                 end
 
@@ -731,10 +702,7 @@ module Magick
                     @text_attrs.writing_mode = mode
                     nil
                 end
-
             end     # class GraphicContext
-
         end # class Utility
     end # class RVG
 end # module Magick
-
